==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1APIVersionsFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1APIVersionsFluent<A extends V1APIVersionsFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A addToServerAddressByClientCIDRs(int index,V1ServerAddressByClientCIDR item);
    public A setToServerAddressByClientCIDRs(int index,V1ServerAddressByClientCIDR item);
    public A addToServerAddressByClientCIDRs(V1ServerAddressByClientCIDR... items);
    public A addAllToServerAddressByClientCIDRs(Collection<V1ServerAddressByClientCIDR> items);
    public A removeFromServerAddressByClientCIDRs(V1ServerAddressByClientCIDR... items);
    public A removeAllFromServerAddressByClientCIDRs(Collection<V1ServerAddressByClientCIDR> items);
    
/**
 * This method has been deprecated, please use method buildServerAddressByClientCIDRs instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ServerAddressByClientCIDR> getServerAddressByClientCIDRs();
    public List<V1ServerAddressByClientCIDR> buildServerAddressByClientCIDRs();
    public V1ServerAddressByClientCIDR buildServerAddressByClientCIDR(int index);
    public V1ServerAddressByClientCIDR buildFirstServerAddressByClientCIDR();
    public V1ServerAddressByClientCIDR buildLastServerAddressByClientCIDR();
    public V1ServerAddressByClientCIDR buildMatchingServerAddressByClientCIDR(io.kubernetes.client.fluent.Predicate<V1ServerAddressByClientCIDRBuilder> predicate);
    public A withServerAddressByClientCIDRs(List<V1ServerAddressByClientCIDR> serverAddressByClientCIDRs);
    public A withServerAddressByClientCIDRs(V1ServerAddressByClientCIDR... serverAddressByClientCIDRs);
    public Boolean hasServerAddressByClientCIDRs();
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> addNewServerAddressByClientCIDR();
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> addNewServerAddressByClientCIDRLike(V1ServerAddressByClientCIDR item);
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> setNewServerAddressByClientCIDRLike(int index,V1ServerAddressByClientCIDR item);
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> editServerAddressByClientCIDR(int index);
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> editFirstServerAddressByClientCIDR();
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> editLastServerAddressByClientCIDR();
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> editMatchingServerAddressByClientCIDR(io.kubernetes.client.fluent.Predicate<V1ServerAddressByClientCIDRBuilder> predicate);
    public A addToVersions(int index,String item);
    public A setToVersions(int index,String item);
    public A addToVersions(String... items);
    public A addAllToVersions(Collection<String> items);
    public A removeFromVersions(String... items);
    public A removeAllFromVersions(Collection<String> items);
    public List<String> getVersions();
    public String getVersion(int index);
    public String getFirstVersion();
    public String getLastVersion();
    public String getMatchingVersion(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withVersions(List<String> versions);
    public A withVersions(String... versions);
    public Boolean hasVersions();

    public interface ServerAddressByClientCIDRsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ServerAddressByClientCIDRFluent<V1APIVersionsFluent.ServerAddressByClientCIDRsNested<N>>{

        
    public N and();    public N endServerAddressByClientCIDR();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1APIVersionsFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1APIVersionsFluent<A extends V1APIVersionsFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public A addToServerAddressByClientCIDRs(int index,V1ServerAddressByClientCIDR item);
    public A setToServerAddressByClientCIDRs(int index,V1ServerAddressByClientCIDR item);
    public A addToServerAddressByClientCIDRs(V1ServerAddressByClientCIDR... items);
    public A addAllToServerAddressByClientCIDRs(Collection<V1ServerAddressByClientCIDR> items);
    public A removeFromServerAddressByClientCIDRs(V1ServerAddressByClientCIDR... items);
    public A removeAllFromServerAddressByClientCIDRs(Collection<V1ServerAddressByClientCIDR> items);
    
/**
 * This method has been deprecated, please use method buildServerAddressByClientCIDRs instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ServerAddressByClientCIDR> getServerAddressByClientCIDRs();
    public List<V1ServerAddressByClientCIDR> buildServerAddressByClientCIDRs();
    public V1ServerAddressByClientCIDR buildServerAddressByClientCIDR(int index);
    public V1ServerAddressByClientCIDR buildFirstServerAddressByClientCIDR();
    public V1ServerAddressByClientCIDR buildLastServerAddressByClientCIDR();
    public V1ServerAddressByClientCIDR buildMatchingServerAddressByClientCIDR(io.kubernetes.client.fluent.Predicate<V1ServerAddressByClientCIDRBuilder> predicate);
    public Boolean hasMatchingServerAddressByClientCIDR(io.kubernetes.client.fluent.Predicate<V1ServerAddressByClientCIDRBuilder> predicate);
    public A withServerAddressByClientCIDRs(List<V1ServerAddressByClientCIDR> serverAddressByClientCIDRs);
    public A withServerAddressByClientCIDRs(V1ServerAddressByClientCIDR... serverAddressByClientCIDRs);
    public Boolean hasServerAddressByClientCIDRs();
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> addNewServerAddressByClientCIDR();
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> addNewServerAddressByClientCIDRLike(V1ServerAddressByClientCIDR item);
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> setNewServerAddressByClientCIDRLike(int index,V1ServerAddressByClientCIDR item);
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> editServerAddressByClientCIDR(int index);
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> editFirstServerAddressByClientCIDR();
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> editLastServerAddressByClientCIDR();
    public V1APIVersionsFluent.ServerAddressByClientCIDRsNested<A> editMatchingServerAddressByClientCIDR(io.kubernetes.client.fluent.Predicate<V1ServerAddressByClientCIDRBuilder> predicate);
    public A addToVersions(int index,String item);
    public A setToVersions(int index,String item);
    public A addToVersions(String... items);
    public A addAllToVersions(Collection<String> items);
    public A removeFromVersions(String... items);
    public A removeAllFromVersions(Collection<String> items);
    public List<String> getVersions();
    public String getVersion(int index);
    public String getFirstVersion();
    public String getLastVersion();
    public String getMatchingVersion(io.kubernetes.client.fluent.Predicate<String> predicate);
    public Boolean hasMatchingVersion(io.kubernetes.client.fluent.Predicate<String> predicate);
    public A withVersions(List<String> versions);
    public A withVersions(String... versions);
    public Boolean hasVersions();
    public A addNewVersion(String arg1);
    public A addNewVersion(StringBuilder arg1);
    public A addNewVersion(StringBuffer arg1);

    public interface ServerAddressByClientCIDRsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ServerAddressByClientCIDRFluent<V1APIVersionsFluent.ServerAddressByClientCIDRsNested<N>>{

        
    public N and();    public N endServerAddressByClientCIDR();
}


}
